#!/usr/bin/env python3
"""Validation script for ToolsPanel refactoring."""

import sys
import os

# Add parent directory to path to import utils
sys.path.insert(0, os.path.dirname(os.path.abspath(__file__)))

from utils.validation_common import (
    validate_jsx_component,
    count_complexity,
    print_validation_header,
    print_complexity_analysis,
    print_summary_footer,
    run_validation,
)


def main():
    """Validate ToolsPanel refactoring."""
    # Components to validate
    components = {
        'ToolsRegistry.jsx': ['ToolsRegistry'],
        'ToolsJobQueue.jsx': ['ToolsJobQueue'],
        'ToolsDispatch.jsx': ['ToolsDispatch'],
        'ToolsPanelRefactored.jsx': ['ToolsPanelRefactored']
    }
    
    base_path = 'src/proxym/dashboard/components/tools'
    original_file = 'src/proxym/dashboard/components/tools.jsx'
    
    benefits_text = """  ✅ Separated concerns into focused components
  ✅ Improved reusability of tool management logic
  ✅ Enhanced testability with isolated components
  ✅ Better maintainability through modular design"""
    
    return run_validation(
        title="ToolsPanel Refactoring",
        components=components,
        base_path=base_path,
        original_file=original_file,
        benefits_text=benefits_text
    )

if __name__ == "__main__":
    main()
